ExprCtxView

Struct ExprCtxView 

pub struct ExprCtxView<'i> { /* private fields */ }
Accessor for ExprCtx. This is not Copy or even Clone, so if you need to duplicate it you should use the fork! macro that will reborrow a fresh copy.